@@ -1,10 +1,15 @@
 # parser default cfg
 stack = role = type = topics = stack_args = []
-region = jobs = pause = version = template = None
-nowait = compact = dryrun = answer_yes = None
+parallel = region = jobs = pause = version = template = None
+nowait = compact = dryrun = answer_yes = no_stacks = all_stacks = None
+debug = False
 max_retry_ecs_service_running_count = 0
 timedelta = 300
 dashboard = 'OnChange'
+statistic = 'Average'
+statisticresponse = 'p95'
+silent = True
+vertical = False
 #
 
 OUT_WIDTH = 1000000
@@ -13,6 +18,8 @@ SLACK_CHANNEL = '_cf_deploy'
 
 MAX_SINGLE_STACKS = 5
 
+ACTION_WAITER_SLEEP_TIME = 3
+
 STACK_BASE_DATA = [
     'StackName',
     'Description',
@@ -38,6 +45,7 @@ RESOURCES_MAP = {
     'ScalableTarget': 'ClusterName',
     'ListenerHttpsExternalRules1': 'LoadBalancerExternal',
     'ListenerHttpsExternalRules2': 'LoadBalancerExternal',
+    'ListenerHttpExternalRules1': 'LoadBalancerExternal',
     'ListenerHttpInternalRules1': 'LoadBalancerInternal',
     'AlarmCPUHigh': None,
     'AlarmCPULow': None,
@@ -51,6 +59,14 @@ SCALING_POLICY_TRACKINGS_NAMES = {
 }
 RESOURCES_MAP.update(SCALING_POLICY_TRACKINGS_NAMES)
 
+RESOURCES_MAP_R53 = {
+    'RecordSetExternal': None,
+    'RecordSetInternal': None,
+    'RecordSetExternalRO': None,
+    'RecordSetInternalRO': None,
+    'RecordSetCloudFront': None,
+}
+
 STACK_COMPLETE_STATUS = [
     'UPDATE_COMPLETE',
     'CREATE_COMPLETE',
@@ -74,6 +90,7 @@ SHOW_TABLE_FIELDS = [
     'StackType',
     'UpdateMode',
     'EnvApp1Version',
+    'StackStatus',
     'LastUpdatedTime',
 ]
 
